@@ -8,8 +8,7 @@
 #include <gnome.h>
 
 #include "callbacks.h"
-#include "interface.h"
-#include "support.h"
+#include <schedwi_interface.h>
 
 
 #include <hosts_cb.h>
@@ -81,9 +80,7 @@ void
 on_about2_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	GtkWidget *about;
-	about = create_about1 ();
-	gtk_widget_show (about);
+	schedwi_main_about ();
 }
 
 
@@ -1670,6 +1667,14 @@ on_waiting1_activate                   (GtkMenuItem     *menuitem,
 }
 
 
+void
+on_completed_or_failed1_activate       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+
+}
+
+
 void
 on_statistics1_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -1710,6 +1715,14 @@ on_waiting2_activate                   (GtkMenuItem     *menuitem,
 }
 
 
+void
+on_completed_or_failed2_activate       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	link_menu_change_completed_or_failed (menuitem);
+}
+
+
 void
 on_delete2_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -1780,3 +1793,21 @@ on_background_paste_activate           (GtkMenuItem     *menuitem,
 	background_menu_paste_job (menuitem);
 }
 
+
+
+void
+on_checkbutton_job_h_retries_toggled   (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	job_cb_h_retries_toggled (togglebutton);
+}
+
+
+void
+on_checkbutton_job_h_retries_interval_toggled
+                                        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	job_cb_h_retries_interval_toggled (togglebutton);
+}
+
