@@ -855,6 +855,10 @@ void
 on_waiting1_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_completed_or_failed1_activate       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
 void
 on_statistics1_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -875,6 +879,10 @@ void
 on_waiting2_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_completed_or_failed2_activate       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
 void
 on_delete2_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -910,3 +918,12 @@ on_copy2_activate                      (GtkMenuItem     *menuitem,
 void
 on_background_paste_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+
+void
+on_checkbutton_job_h_retries_toggled   (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_checkbutton_job_h_retries_interval_toggled
+                                        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
