@@ -1,28 +1,27 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
-   This program is free software; you can redistribute it and/or modify
+
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
-     
-   This program is distributed in the hope that it will be useful,
+
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
-     
+   GNU General Public License for more details.
+
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* child_job.c -- Structure to draw a job/jobset on a GnomeCanvas */
 
 #include <schedwi.h>
 
-#include "support.h"
-#include "interface.h"
+#include <schedwi_interface.h>
 
 #include <math.h>
 
@@ -1171,6 +1170,12 @@ view_popup_menu_job (GdkEventButton *event, child_job_t *ptr)
 			gtk_menu_item_set_submenu (	GTK_MENU_ITEM (item),
 							job_menu);
 
+			item = lookup_widget (links, "completed_or_failed1");
+			job_menu = child_job_build_job_menu (l,
+					JOB_STATUS_STATE_COMPLETED_OR_FAILED);
+			gtk_menu_item_set_submenu (	GTK_MENU_ITEM (item),
+							job_menu);
+
 			g_slist_foreach (l, child_job_item_free, NULL);
 			g_slist_free (l);
 		}
