@@ -1,19 +1,20 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
 
-   This program is free software; you can redistribute it and/or modify
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* env_widget.c - Environment choice widget */
@@ -32,8 +33,7 @@
 #endif
 #endif
 
-#include "support.h"
-#include "interface.h"
+#include <schedwi_interface.h>
 
 #include <message_windows.h>
 #include <cursor.h>
@@ -223,12 +223,15 @@ add_environment_combo (void *ptr, const char *id, const char *name)
 	GtkWidget *combo = ptr;
 	GSList *list;
 	GPtrArray *env_item;
+	GtkWidget *dialog_choose;
 
 	/* Add the name in the combo box list */
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), name);
 
 	/* Retrieve the list of the combo box items */
-	list = (GSList *) g_object_get_data (G_OBJECT (combo), "list");
+	dialog_choose = lookup_widget (combo, "dialog_env_choose");
+	list = (GSList *) g_object_get_data (	G_OBJECT (dialog_choose),
+						"list");
 
 	/* Build an array of two strings: the environment id and name */
 	env_item = g_ptr_array_sized_new (2);
@@ -244,7 +247,7 @@ add_environment_combo (void *ptr, const char *id, const char *name)
 	 * destroyed (the callback of the destroy event is the
 	 * env_widget_env_dialog_choose_destroy() function)
 	 */
-	g_object_set_data (G_OBJECT (combo), "list", list);
+	g_object_set_data (G_OBJECT (dialog_choose), "list", list);
 
 	return 0;
 }
@@ -311,11 +314,12 @@ env_widget_env_choose_clicked (GtkButton *button)
 	/* Retrieve the required objects */
 	dialog_choose = lookup_widget (	GTK_WIDGET (button),
 					"dialog_env_choose");
-	combo = lookup_widget (GTK_WIDGET (button), "combobox_env_choose");
+	combo = lookup_widget (	GTK_WIDGET (dialog_choose),
+				"combobox_env_choose");
 	ptr = (env_widget_ptr) g_object_get_data (	G_OBJECT (combo),
 							"env_widget");
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ptr->view));
-	envs = (GSList *) g_object_get_data (G_OBJECT (combo), "list");
+	envs = (GSList *) g_object_get_data (G_OBJECT (dialog_choose), "list");
 	selected_env = gtk_combo_box_get_active_text (GTK_COMBO_BOX (combo));
 
 	/*
@@ -399,13 +403,10 @@ env_list_free (GSList *lst)
 void
 env_widget_env_choose_destroy (GtkObject *dialog_choose)
 {
-	GtkWidget *combo;
 	GSList *envs;
 
-	combo = lookup_widget (	GTK_WIDGET (dialog_choose),
-				"combobox_env_choose");
 	/* Free the environment list */
-	envs = (GSList *) g_object_get_data (G_OBJECT (combo), "list");
+	envs = (GSList *) g_object_get_data (G_OBJECT (dialog_choose), "list");
 	env_list_free (envs);
 }
 
@@ -450,6 +451,12 @@ env_widget_add_clicked (GtkButton *button, gpointer user_data)
 	combo = lookup_widget (dialog_choose, "combobox_env_choose");
 	g_object_set_data (G_OBJECT (combo), "env_widget", (gpointer)ptr);
 
+	/*
+	 * Clear the first item added in glade for libglade to use
+	 * gtk_combo_box_new_text() instead of gtk_combo_box_new()
+	 */
+	gtk_combo_box_remove_text (GTK_COMBO_BOX (combo), 0);
+
 	/* Retrieve the available environments */
 	nb = sql_env_list (	current_lst,
 				add_environment_combo, combo,
