@@ -1,20 +1,20 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
 
-   This program is free software; you can redistribute it and/or modify
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* job_cb.c -- GUI functions for the job/jobset window */
@@ -33,8 +33,7 @@
 #endif
 #endif
 
-#include "support.h"
-#include "interface.h"
+#include <schedwi_interface.h>
 
 #include <schedwi_g_utils.h>
 #include <cache_pixbuf.h>
@@ -306,6 +305,12 @@ job_set_hostname (char **values, char **values_parent, GtkWidget *dialog_job)
 
 	combo = lookup_widget (dialog_job, "combobox_job_host");
 
+	/*
+	 * Clear the first item added in glade for libglade to use
+	 * gtk_combo_box_new_text() instead of gtk_combo_box_new()
+	 */
+	gtk_combo_box_remove_text (GTK_COMBO_BOX (combo), 0);
+
 	/* Store the values in the widget */
 	g_object_set_data_full (G_OBJECT (combo), "values",
 				(gpointer)values,
@@ -1304,6 +1309,46 @@ dialog_job_init (	GtkWidget *dialog_job,
 		return -1;
 	}
 
+	/* Number of retries */
+	if (sql_job_hierarchy_get (	hierarchy_ptr,
+					"job_retries",
+					"retries",
+					&values, NULL,
+					&values_parent, NULL) != 0)
+	{
+		sql_job_hierarchy_destroy (hierarchy_ptr);
+		return -1;
+	}
+	if (job_set_spin (	values, values_parent, dialog_job,
+				"spinbutton_job_retries",
+				"checkbutton_job_h_retries") == FALSE)
+	{
+		sql_job_hierarchy_destroy (hierarchy_ptr);
+		sql_free_row (values);
+		sql_free_row (values_parent);
+		return -1;
+	}
+
+	/* Interval between retries */
+	if (sql_job_hierarchy_get (	hierarchy_ptr,
+					"job_retries_interval",
+					"retries_interval",
+					&values, NULL,
+					&values_parent, NULL) != 0)
+	{
+		sql_job_hierarchy_destroy (hierarchy_ptr);
+		return -1;
+	}
+	if (job_set_spin (	values, values_parent, dialog_job,
+				"spinbutton_job_retries_interval",
+				"checkbutton_job_h_retries_interval") == FALSE)
+	{
+		sql_job_hierarchy_destroy (hierarchy_ptr);
+		sql_free_row (values);
+		sql_free_row (values_parent);
+		return -1;
+	}
+
 	/* Load user environment */
 	if (sql_job_hierarchy_get (	hierarchy_ptr,
 					"job_loadenv",
@@ -1491,6 +1536,16 @@ dialog_job_init (	GtkWidget *dialog_job,
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
 		gtk_widget_destroy (w);
 
+		w = lookup_widget (	dialog_job,
+					"checkbutton_job_h_retries");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
+		gtk_widget_destroy (w);
+
+		w = lookup_widget (	dialog_job,
+					"checkbutton_job_h_retries_interval");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
+		gtk_widget_destroy (w);
+
 		w = lookup_widget (dialog_job, "checkbutton_job_h_command");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
 		gtk_widget_destroy (w);
@@ -3162,6 +3217,16 @@ job_cb_update (GtkWidget *dialog_job, job_cb_params_ptr ptr)
 					"checkbutton_job_h_max_duration",
 					"job_max_duration",
 					"max_duration") == FALSE
+		|| job_cb_save_spin (	dialog_job, ptr, ptr->id,
+					"spinbutton_job_retries",
+					"checkbutton_job_h_retries",
+					"job_retries",
+					"retries") == FALSE
+		|| job_cb_save_spin (	dialog_job, ptr, ptr->id,
+					"spinbutton_job_retries_interval",
+					"checkbutton_job_h_retries_interval",
+					"job_retries_interval",
+					"retries_interval") == FALSE
 		|| job_cb_save_icon (	dialog_job, ptr, ptr->id,
 					"image_job_default",
 					"checkbutton_job_icon_h_default",
@@ -3287,6 +3352,16 @@ job_cb_save (GtkWidget *dialog_job, job_cb_params_ptr ptr)
 					"checkbutton_job_h_max_duration",
 					"job_max_duration",
 					"max_duration") == FALSE
+		|| job_cb_save_spin (	dialog_job, ptr, id,
+					"spinbutton_job_retries",
+					"checkbutton_job_h_retries",
+					"job_retries",
+					"retries") == FALSE
+		|| job_cb_save_spin (	dialog_job, ptr, id,
+					"spinbutton_job_retries_interval",
+					"checkbutton_job_h_retries_interval",
+					"job_retries_interval",
+					"retries_interval") == FALSE
 		|| job_cb_save_icon (	dialog_job, ptr, id,
 					"image_job_default",
 					"checkbutton_job_icon_h_default",
@@ -3343,6 +3418,8 @@ job_cb_save (GtkWidget *dialog_job, job_cb_params_ptr ptr)
 					NULL, NULL);
 		sql_job_hierarchy_del (id, "job_start_limit", NULL, NULL);
 		sql_job_hierarchy_del (id, "job_max_duration", NULL, NULL);
+		sql_job_hierarchy_del (id, "job_retries", NULL, NULL);
+		sql_job_hierarchy_del (id, "job_retries_interval", NULL, NULL);
 		sql_job_hierarchy_del (id, "job_icon_default", NULL, NULL);
 		sql_job_hierarchy_del (id, "job_icon_waiting", NULL, NULL);
 		sql_job_hierarchy_del (id, "job_icon_running", NULL, NULL);
