@@ -1,27 +1,27 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
 
-   This program is free software; you can redistribute it and/or modify
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* pref_cb.c -- GUI functions for the preferences window */
 
 #include <schedwi.h>
 
-#include "support.h"
-#include "interface.h"
+#include <schedwi_interface.h>
 
 #include <math.h>
 
@@ -643,9 +643,10 @@ init_pref (GtkWidget *widget)
 	v = gconf_client_get_int (	schedwi_gconf,
 					GCONF_PATH "/ui/grid/width",
 					NULL);
-	if (v != 0) {
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), v);
+	if (v == 0) {
+		v = 50;
 	}
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), v);
 	gtk_widget_set_sensitive (w, gconf_client_key_is_writable (
 						schedwi_gconf,
 						GCONF_PATH "/ui/grid/width",
@@ -658,9 +659,10 @@ init_pref (GtkWidget *widget)
 	v = gconf_client_get_int (	schedwi_gconf,
 					GCONF_PATH "/ui/grid/height",
 					NULL);
-	if (v != 0) {
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), v);
+	if (v == 0) {
+		v = 50;
 	}
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), v);
 	gtk_widget_set_sensitive (w, gconf_client_key_is_writable (
 						schedwi_gconf,
 						GCONF_PATH "/ui/grid/height",
